      subroutine valueAndSlope(rho,rhoC,momC,dir,centSide, DmomDrho,mom)
      implicit none
c
c     Works with the projections of wave-curves on the (rho,mom)-plane.
c     Wave curves are parametrized with density, rho.
c
c     Given rho (state W on the wave-curve is defined), the subroutine
c     computes momentum, mom, and D(momemntum)/D(density), DmomDrho.
c
c         state W lies ON a general wave-curve and is defined by rho;
c         the wave-curve is centered at state C.
c     
c     C is the state at which the wave-curve is centered.
c     With respect to the wave, 
c     state C could be either Ahead or Behind.
c             rhoC --- density  at state C
c             momC --- momentum at state C 
c
c     W is the state ON the wave-curve at which the VALUE is computed.
c     (W is the side of the wave opposite to C)
c     With respect to the wave, 
c     state W could be either Behind or Ahead.
c             rho --- density at state W
c
c     The state at which the wave-curve is centered is defined
c     by a pair {rhoC,momC}.
c     The wave curve is parametrized with the density, rho. 
c 
c     Whether C is Ahead (Behind) and W is Behind (Ahead)
c     depends on the value of centSide
c             centSide =  -1 state C is Behind, state W is Ahead
c                         +1 state C  is Ahead, state W is Behind
c
c     dir  --- -1 1-wave-curve
c              +1 2-wave-curve
c 
c     Output: mom      --- value of the momentum on the wave-curve
c             DmomDrho --- D(momemntum)/D(density) on the wave-curve
c
c


c     Input:
      real*8 rho,rhoC,momC
      integer dir,centSide
c     Output:
      real*8 DmomDrho,mom
c     Auxiliary:
      real*8 onWaveCurve
      external rho2DmomDrhoExpan,rho2DmomDrhoCompr
      real*8 rho2DmomDrhoExpan,rho2DmomDrhoCompr
      external rho2momExpan,rho2momCompr
      real*8 rho2momExpan,rho2momCompr

      mom = onWaveCurve(rho,rhoC,momC,dir,centSide,
     &        rho2momExpan,rho2momCompr)

      DmomDrho = onWaveCurve(rho,rhoC,momC,dir,centSide,
     &        rho2DmomDrhoExpan,rho2DmomDrhoCompr)

      end
