      subroutine wave(rhoB,momB,rhoA,momA,dir,
     &     wB,wA,signif,wave_type)
      implicit none
c
c-----------------------------------------------------------------------
c                              INPUT 
c-----------------------------------------------------------------------
c
c         BEHIND STATE VARIABLES
c         ----------------------
c    rhoB  density
c    momB  momentum
c
c         AHEAD STATE VARIABLES
c         ---------------------
c    rhoA  density
c    momA  momentum
c
c    dir  wave direction parameter
c        =-1 for left-facing wave
c        = 1 for right-facing wave
c
c-----------------------------------------------------------------------
c                            OUTPUT 
c-----------------------------------------------------------------------
c
c    wB velocity of the behind-edge of the fan
c    wA velocity of the ahead-edge of the fan
c
c-----------------------------------------------------------------------
c
c    signif
c            = SIGNIFICANT if the wave is signigicant 
c            = INSIGNIFICANT otherwise
c       THIS INFORMATION IS GIVEN FOR WAVE TRACKING PURPOSES: 
c       signif = SIGNIFICANT: the wave should be tracked
c       signif = INSIGNIFICANT: the wave should not be tracked
c
c-----------------------------------------------------------------------
c
c    wave_type  -- type of the wave
c            = RFN  rarefaction fan
c            = SFR  shock front
c
      include 'wave_constants.h'

c     Input.
      real*8 rhoB,momB,rhoA,momA
      integer dir
c     Output.
      real*8 wB,wA
      integer signif, wave_type
c     Auxiliary.
      real*8 st2W,st2char

c
      if (rhoB .gt. rhoA) then
c        front
         wave_type = SFR
         wB = st2W(rhoB,momB,rhoA,momA,dir)
         wA = wB
      else
c        fan
         wave_type = RFN
         wB = st2char(rhoB,momB,dir)
         wA = st2char(rhoA,momA,dir)
      endif

      signif = SIGNIFICANT

      end
